@@ -5,10 +5,10 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#ifndef __IXION_CONFIG_HPP__
-#define __IXION_CONFIG_HPP__
+#ifndef INCLUDED_IXION_CONFIG_HPP
+#define INCLUDED_IXION_CONFIG_HPP
 
-#include "ixion/env.hpp"
+#include "ixion/types.hpp"
 
 namespace ixion {
 
@@ -23,6 +23,22 @@ struct IXION_DLLPUBLIC config
      */
     char sep_function_arg;
 
+    /**
+     * Matrix column separator.
+     */
+    char sep_matrix_column;
+
+    /**
+     * Matrix row separator.
+     */
+    char sep_matrix_row;
+
+    /**
+     * Precision to use when converting a numeric value to a string
+     * representation.  A negative value indicates an unspecified precision.
+     */
+    int8_t output_precision;
+
     config();
     config(const config& r);
 };
@@ -30,4 +46,5 @@ struct IXION_DLLPUBLIC config
 }
 
 #endif
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
